==> ejc-zdsmaterialb-api-3.0.0-20241015.015712-31-sources.jar: com/ejianc/business/zdsmaterial/material/vo/MaterialCategoryPropertySubItemVO.java <==
package com.ejianc.business.zdsmaterial.material.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 材料分类属性可选值
 * 
 * @author generator
 * 
 */
@ApiModel("材料分类属性可选值")
public class MaterialCategoryPropertySubItemVO extends BaseVO {

    private static final long serialVersionUID = -2728726302591820619L;

    @ApiModelProperty("属性值")
    private String name;
    @ApiModelProperty("属性值排序号")
    private Integer sequence;
    @ApiModelProperty("停启用标识：0-停用，1-启用")
    private Integer enabled;
    @ApiModelProperty("生效标识：0-未生效, 1-已生效")
    private Integer validFlag;
    @ApiModelProperty("未生效时可使用该属性的用户")
    private String relatedUserIds;
    @ApiModelProperty("所属分类Id")
    private Long categoryId;
    @ApiModelProperty("所属属性Id")
    private Long propertyId;

    @ApiModelProperty("产品代码")
    private String productCode;

    /*** 导入使用字段 **/
    private String description;

    //旧属性值
    private String oldName;
    private String oldProductCode;

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getOldProductCode() {
        return oldProductCode;
    }

    public void setOldProductCode(String oldProductCode) {
        this.oldProductCode = oldProductCode;
    }

    public Integer getValidFlag() {
        return validFlag;
    }

    public void setValidFlag(Integer validFlag) {
        this.validFlag = validFlag;
    }

    public String getRelatedUserIds() {
        return relatedUserIds;
    }

    public void setRelatedUserIds(String relatedUserIds) {
        this.relatedUserIds = relatedUserIds;
    }

    public String getOldName() {
        return oldName;
    }

    public void setOldName(String oldName) {
        this.oldName = oldName;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public Long getPropertyId() {
        return propertyId;
    }

    public void setPropertyId(Long propertyId) {
        this.propertyId = propertyId;
    }
    
}

==> ejc-zdsmaterialb-api-3.0.0-20251206.064345-102-sources.jar: com/ejianc/business/zdsmaterial/material/vo/MaterialCategoryPropertySubItemVO.java <==
package com.ejianc.business.zdsmaterial.material.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 材料分类属性可选值
 * 
 * @author generator
 * 
 */
@ApiModel("材料分类属性可选值")
public class MaterialCategoryPropertySubItemVO extends BaseVO {

    private static final long serialVersionUID = -2728726302591820619L;

    @ApiModelProperty("属性值")
    private String name;
    @ApiModelProperty("属性值排序号")
    private Integer sequence;
    @ApiModelProperty("停启用标识：0-停用，1-启用")
    private Integer enabled;
    @ApiModelProperty("生效标识：0-未生效, 1-已生效")
    private Integer validFlag;
    @ApiModelProperty("未生效时可使用该属性的用户")
    private String relatedUserIds;
    @ApiModelProperty("所属分类Id")
    private Long categoryId;
    @ApiModelProperty("所属属性Id")
    private Long propertyId;

    @ApiModelProperty("产品代码")
    private String productCode;

    /*** 导入使用字段 **/
    private String description;

    //旧属性值
    private String oldName;
    private String oldProductCode;

    private String categoryName;
    private String propertyName;

    private Integer propertySeq; //所属属性排序号 非数据库字段

    //AI识别需用字段 非数据库字段
    private Integer hasNewPropertyVal;
    private Integer productCodeFlag;
    private Integer keyPropertyFlag;
    private Integer requiredFlag;

    public Integer getHasNewPropertyVal() {
        return hasNewPropertyVal;
    }

    public void setHasNewPropertyVal(Integer hasNewPropertyVal) {
        this.hasNewPropertyVal = hasNewPropertyVal;
    }

    public Integer getProductCodeFlag() {
        return productCodeFlag;
    }

    public void setProductCodeFlag(Integer productCodeFlag) {
        this.productCodeFlag = productCodeFlag;
    }

    public Integer getKeyPropertyFlag() {
        return keyPropertyFlag;
    }

    public void setKeyPropertyFlag(Integer keyPropertyFlag) {
        this.keyPropertyFlag = keyPropertyFlag;
    }

    public Integer getRequiredFlag() {
        return requiredFlag;
    }

    public void setRequiredFlag(Integer requiredFlag) {
        this.requiredFlag = requiredFlag;
    }

    public Integer getPropertySeq() {
        return propertySeq;
    }

    public void setPropertySeq(Integer propertySeq) {
        this.propertySeq = propertySeq;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public String getPropertyName() {
        return propertyName;
    }

    public void setPropertyName(String propertyName) {
        this.propertyName = propertyName;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getOldProductCode() {
        return oldProductCode;
    }

    public void setOldProductCode(String oldProductCode) {
        this.oldProductCode = oldProductCode;
    }

    public Integer getValidFlag() {
        return validFlag;
    }

    public void setValidFlag(Integer validFlag) {
        this.validFlag = validFlag;
    }

    public String getRelatedUserIds() {
        return relatedUserIds;
    }

    public void setRelatedUserIds(String relatedUserIds) {
        this.relatedUserIds = relatedUserIds;
    }

    public String getOldName() {
        return oldName;
    }

    public void setOldName(String oldName) {
        this.oldName = oldName;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public Long getPropertyId() {
        return propertyId;
    }

    public void setPropertyId(Long propertyId) {
        this.propertyId = propertyId;
    }
    
}
